//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Base/Vector/Direction.cpp
//! @brief     Implements class Direction.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "Base/Vector/Direction.h"
#include "Base/Math/Constants.h"
#include <cmath>

R3 vecOfLambdaAlphaPhi(double _lambda, double _alpha, double _phi)
{
    return Direction(_alpha, -_phi).ZFrameVector(M_TWOPI / _lambda);
}

R3 Direction::ZFrameVector(double length) const
{
    return {length * std::cos(m_alpha) * std::cos(m_phi),
            length * std::cos(m_alpha) * std::sin(m_phi), length * std::sin(m_alpha)};
}
