//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Base/Vector/Direction.h
//! @brief     Defines class Direction.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifdef SWIG
#error no need to expose this header to Swig
#endif // SWIG
#ifndef BORNAGAIN_BASE_VECTOR_DIRECTION_H
#define BORNAGAIN_BASE_VECTOR_DIRECTION_H

#include <heinz/Vectors3D.h>

R3 vecOfLambdaAlphaPhi(double _lambda, double _alpha, double _phi);

//! A direction in three-dimensional space.

class Direction {
public:
    Direction(double alpha, double phi)
        : m_alpha(alpha)
        , m_phi(phi)
    {
    }

    double alpha() const { return m_alpha; }
    double phi() const { return m_phi; }

    //! Returns Cartesian 3D vector, in a frame where alpha=0 is on the +z axis.
    R3 ZFrameVector(double length) const;

    Direction zReflected() const { return {-m_alpha, m_phi}; }

private:
    double m_alpha;
    double m_phi;
};

#endif // BORNAGAIN_BASE_VECTOR_DIRECTION_H
